==> ejc-settle-impl-3.0.0-20240618.002543-48-sources.jar: com/ejianc/business/settle/bean/SettlementCenterAlertInfoEntity.java <==
package com.ejianc.business.settle.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 预警信息表
 *
 * @author generator
 */
@TableName("settlement_center_alert_info")
public class SettlementCenterAlertInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "id")
    private Long id; // 主键id
    @TableField(value = "third_node_user_id")
    private Long thirdNodeUserId; // 结算中心专职(被预警人)
    @TableField(value = "dr")
    private Integer dr; // '删除标识（0：未删，1：删除）'
    @TableField(value = "project_id")
    private Long projectId; // 项目id
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "dc_drwgrp_info_name")
    private String dcDrwgrpInfoName; // 卷册名称
    @TableField(value = "create_time")
    private Date createTime; // 创建时间
    @TableField(value = "update_time")
    private Date updateTime; // 修改时间
    @TableField(value = "settlement_center_major")
    private Long settlementCenterMajor; // 结算中心专业
    @TableField(value = "alert_last_time")
    private Date alertLastTime; // 24小时预警时间
    @TableField(value = "alert_now_time")
    private Date alertNowTime; // 截止时间
    @TableField(value = "alert_type")
    private Integer alertType; // '预警类型（0：24h预警，1：截止日期预警）'
    @TableField(value = "tenant_id")
    private Long tenantId; // 租户主键
    @TableField(value = "org_id")
    private Long orgId; // 组织id

    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织id
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态


    @TableField(value = "third_node_user_name")
    private String thirdNodeUserName; // 节点3结算中心专职人员名字

    public String getThirdNodeUserName() {
        return thirdNodeUserName;
    }

    public void setThirdNodeUserName(String thirdNodeUserName) {
        this.thirdNodeUserName = thirdNodeUserName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    @Override
    public Long getTenantId() {
        return tenantId;
    }

    @Override
    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    public Integer getAlertType() {
        return alertType;
    }

    public void setAlertType(Integer alertType) {
        this.alertType = alertType;
    }

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    public Long getThirdNodeUserId() {
        return thirdNodeUserId;
    }

    public void setThirdNodeUserId(Long thirdNodeUserId) {
        this.thirdNodeUserId = thirdNodeUserId;
    }

    @Override
    public Integer getDr() {
        return dr;
    }

    @Override
    public void setDr(Integer dr) {
        this.dr = dr;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getDcDrwgrpInfoName() {
        return dcDrwgrpInfoName;
    }

    public void setDcDrwgrpInfoName(String dcDrwgrpInfoName) {
        this.dcDrwgrpInfoName = dcDrwgrpInfoName;
    }

    @Override
    public Date getCreateTime() {
        return createTime;
    }

    @Override
    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    @Override
    public Date getUpdateTime() {
        return updateTime;
    }

    @Override
    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Long getSettlementCenterMajor() {
        return settlementCenterMajor;
    }

    public void setSettlementCenterMajor(Long settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }

    public Date getAlertLastTime() {
        return alertLastTime;
    }

    public void setAlertLastTime(Date alertLastTime) {
        this.alertLastTime = alertLastTime;
    }

    public Date getAlertNowTime() {
        return alertNowTime;
    }

    public void setAlertNowTime(Date alertNowTime) {
        this.alertNowTime = alertNowTime;
    }
}

==> ejc-settle-impl-3.0.0-20240708.072402-71-sources.jar: com/ejianc/business/settle/bean/SettlementCenterAlertInfoEntity.java <==
package com.ejianc.business.settle.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 预警信息表
 *
 * @author generator
 */
@TableName("settlement_center_alert_info")
public class SettlementCenterAlertInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "id")
    private Long id; // 主键id
    @TableField(value = "third_node_user_id")
    private String thirdNodeUserId; // 结算中心专职(被预警人)
    @TableField(value = "dr")
    private Integer dr; // '删除标识（0：未删，1：删除）'
    @TableField(value = "project_id")
    private Long projectId; // 项目id
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "dc_drwgrp_info_name")
    private String dcDrwgrpInfoName; // 卷册名称
    @TableField(value = "create_time")
    private Date createTime; // 创建时间
    @TableField(value = "update_time")
    private Date updateTime; // 修改时间
    @TableField(value = "settlement_center_major")
    private Long settlementCenterMajor; // 结算中心专业
    @TableField(value = "alert_last_time")
    private Date alertLastTime; // 24小时预警时间
    @TableField(value = "alert_now_time")
    private Date alertNowTime; // 截止时间
    @TableField(value = "alert_type")
    private Integer alertType; // '预警类型（0：24h预警，1：截止日期预警）'
    @TableField(value = "tenant_id")
    private Long tenantId; // 租户主键
    @TableField(value = "org_id")
    private Long orgId; // 组织id

    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织id
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态


    @TableField(value = "third_node_user_name")
    private String thirdNodeUserName; // 节点3结算中心专职人员名字

    public String getThirdNodeUserName() {
        return thirdNodeUserName;
    }

    public void setThirdNodeUserName(String thirdNodeUserName) {
        this.thirdNodeUserName = thirdNodeUserName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    @Override
    public Long getTenantId() {
        return tenantId;
    }

    @Override
    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    public Integer getAlertType() {
        return alertType;
    }

    public void setAlertType(Integer alertType) {
        this.alertType = alertType;
    }

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    public String getThirdNodeUserId() {
        return thirdNodeUserId;
    }

    public void setThirdNodeUserId(String thirdNodeUserId) {
        this.thirdNodeUserId = thirdNodeUserId;
    }

    @Override
    public Integer getDr() {
        return dr;
    }

    @Override
    public void setDr(Integer dr) {
        this.dr = dr;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getDcDrwgrpInfoName() {
        return dcDrwgrpInfoName;
    }

    public void setDcDrwgrpInfoName(String dcDrwgrpInfoName) {
        this.dcDrwgrpInfoName = dcDrwgrpInfoName;
    }

    @Override
    public Date getCreateTime() {
        return createTime;
    }

    @Override
    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    @Override
    public Date getUpdateTime() {
        return updateTime;
    }

    @Override
    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Long getSettlementCenterMajor() {
        return settlementCenterMajor;
    }

    public void setSettlementCenterMajor(Long settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }

    public Date getAlertLastTime() {
        return alertLastTime;
    }

    public void setAlertLastTime(Date alertLastTime) {
        this.alertLastTime = alertLastTime;
    }

    public Date getAlertNowTime() {
        return alertNowTime;
    }

    public void setAlertNowTime(Date alertNowTime) {
        this.alertNowTime = alertNowTime;
    }
}
